<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'SPIP-Forum (privat an ëffentlech)',
	'forum_slogan' => 'Beaarbechte vun de privaten an ëffentleche Forumen am SPIP',
];
